% Auto-generated chapter 17 for nasai
% Hadiths in this chapter: 25

\hadithdefcmd{nasai}{1504}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الْمَوَاشِي وَانْقَطَعَتِ السُّبُلُ فَادْعُ اللَّهَ عَزَّ وَجَلَّ ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَمُطِرْنَا مِنَ الْجُمُعَةِ إِلَى الْجُمُعَةِ فَجَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ وَانْقَطَعَتِ السُّبُلُ وَهَلَكَتِ الْمَوَاشِي ‏.‏ فَقَالَ ‏ "‏ اللَّهُمَّ عَلَى رُءُوسِ الْجِبَالِ وَالآكَامِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏ ‏.‏ فَانْجَابَتْ عَنِ الْمَدِينَةِ انْجِيَابَ الثَّوْبِ ‏.‏\hadithno{1504}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"A man came to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, the livestock have died and the routes have been cut off; pray to Allah (SWT), the Mighty and Sublime.' So the Messenger of Allah (ﷺ) prayed to Allah (SWT) and it rained from that Friday until the next. Then a man came to the Messenger of Allah (ﷺ) and said: 'The houses have been destroyed, the routes have been cut off and the livestock have died.' He said: 'O Allah, on the tops of the mountains and hills, in the bottom of the valleys and where the trees grow.' So (the rain) was lifted from Al-Madinah like a garment being removed}}
\hadithdefcmd{nasai}{1505}{أَخْبَرَنِي مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، - قَالَ سُفْيَانُ فَسَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي بَكْرٍ فَقَالَ سَمِعْتُهُ مِنْ، عَبَّادِ بْنِ تَمِيمٍ يُحَدِّثُ أَبِي - أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ الَّذِي، أُرِيَ النِّدَاءَ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمُصَلَّى يَسْتَسْقِي فَاسْتَقْبَلَ الْقِبْلَةَ وَقَلَبَ رِدَاءَهُ وَصَلَّى رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا غَلَطٌ مِنِ ابْنِ عُيَيْنَةَ وَعَبْدُ اللَّهِ بْنُ زَيْدٍ الَّذِي أُرِيَ النِّدَاءَ هُوَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَبْدِ رَبِّهِ وَهَذَا عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ ‏.‏\hadithno{1505}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abbad bin Tamim:"Sufyan said: 'I asked 'Abdullah bin Abi Bakr who said: I heard it from Abbad bin Tamim who narrated it from his father, that 'Abdullah bin Zaid, who was shown the call to prayer (in a dream) said: 'The Messenger of Allah (ﷺ) went out to the prayer place to pray for rain. He faced the kiblah and turned his cloak around and prayed two rak'ahs}}
\hadithdefcmd{nasai}{1506}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ هِشَامِ بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، عَنْ أَبِيهِ، قَالَ أَرْسَلَنِي فُلاَنٌ إِلَى ابْنِ عَبَّاسٍ أَسْأَلُهُ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الاِسْتِسْقَاءِ فَقَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَضَرِّعًا مُتَوَاضِعًا مُتَبَذِّلاً فَلَمْ يَخْطُبْ نَحْوَ خُطْبَتِكُمْ هَذِهِ فَصَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1506}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hisham bin Ishaq bin Abdullah bin Kinanah that :His father said: "So and so sent me to ask him how the Messenger of Allah (ﷺ) prayed for rain (Istisqa')." He said: 'The Messenger of Allah (ﷺ) went out beseeching and humble, (dressed) in a state of humility. He did not give a Khutbah like this Khutbah of yours, and he prayed two rak'ahs}}
\hadithdefcmd{nasai}{1507}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَسْقَى وَعَلَيْهِ خَمِيصَةٌ سَوْدَاءُ ‏.‏\hadithno{1507}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abdullah bin Zaid that:The Messenger of Allah (ﷺ) prayed for rain wearing a black khamisah}}
\hadithdefcmd{nasai}{1508}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ هِشَامِ بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الاِسْتِسْقَاءِ فَقَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَبَذِّلاً مُتَوَاضِعًا مُتَضَرِّعًا فَجَلَسَ عَلَى الْمِنْبَرِ فَلَمْ يَخْطُبْ خُطْبَتَكُمْ هَذِهِ وَلَكِنْ لَمْ يَزَلْ فِي الدُّعَاءِ وَالتَّضَرُّعِ وَالتَّكْبِيرِ وَصَلَّى رَكْعَتَيْنِ كَمَا كَانَ يُصَلِّي فِي الْعِيدَيْنِ ‏.‏\hadithno{1508}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hisham binIshaq bin Abdullah bin Kinanah that:His father said: "I asked Ibn 'Abbas how the Messenger of Allah (ﷺ) prayed for rain. He said: 'The Messenger of Allah (ﷺ) went out (dressed) in a state of humility, beseeching and humble. He sat on the minbar but he did not deliver a Khutbah like this Khutbah of yours, rather he kept supplicating, beseeching and saying the takbir, and he prayed two rak'ahs as he used to do during the two 'Eids}}
\hadithdefcmd{nasai}{1509}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ عَمَّهُ، حَدَّثَهُ أَنَّهُ، خَرَجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَسْتَسْقِي فَحَوَّلَ رِدَاءَهُ وَحَوَّلَ لِلنَّاسِ ظَهْرَهُ وَدَعَا ثُمَّ صَلَّى رَكْعَتَيْنِ فَقَرَأَ فَجَهَرَ ‏.‏\hadithno{1509}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abbad bin Tamim that :His paternal uncle had told him that he went out with the Messenger of Allah (ﷺ) to pray for rain. He turned his rida' around, and turned his back to the people, then he prayed two rak'ahs and recited loudly}}
\hadithdefcmd{nasai}{1510}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَسْقَى وَصَلَّى رَكْعَتَيْنِ وَقَلَبَ رِدَاءَهُ ‏.‏\hadithno{1510}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abbad bin Tamim, from his paternal uncle that:The Prophet (ﷺ) prayed for rain, and prayed two rak'ahs, and turned his rida' around}}
\hadithdefcmd{nasai}{1511}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّهُ سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ زَيْدٍ، يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَسْقَى وَحَوَّلَ رِدَاءَهُ حِينَ اسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{1511}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abdullah bin Abi Bakr that:He heard Abbad bin Tamim said: "The Messenger of Allah (ﷺ) went out and prayed for rain, and he turned his rida' around when he turned to the Qiblah}}
\hadithdefcmd{nasai}{1512}{أَخْبَرَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ أَبُو تَقِيٍّ الْحِمْصِيُّ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الاِسْتِسْقَاءِ اسْتَقْبَلَ الْقِبْلَةَ وَقَلَبَ الرِّدَاءَ وَرَفَعَ يَدَيْهِ ‏.‏\hadithno{1512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abbad bin Tamim, from his paternal uncle, that:He saw the Messenger of Allah (ﷺ), when he prayed for rain, turn to face the Qiblah, turning his cloak around and raising his hands}}
\hadithdefcmd{nasai}{1513}{أَخْبَرَنِي شُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنَ الدُّعَاءِ إِلاَّ فِي الاِسْتِسْقَاءِ فَإِنَّهُ كَانَ يَرْفَعُ يَدَيْهِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{1513}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) did not raise his hands during any supplication except when praying for rain, when he used to raise his hands so high that the whiteness of his armpits could be seen}}
\hadithdefcmd{nasai}{1514}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ عُمَيْرٍ، مَوْلَى آبِي اللَّحْمِ عَنْ آبِي اللَّحْمِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ أَحْجَارِ الزَّيْتِ يَسْتَسْقِي وَهُوَ مُقْنِعٌ بِكَفَّيْهِ يَدْعُو ‏.‏\hadithno{1514}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abi Al-Lahm that:He saw the Messenger of Allah at Ahjar Az-Zait praying for rain and raising his hands, making supplications}}
\hadithdefcmd{nasai}{1515}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ، - وَهُوَ الْمَقْبُرِيُّ - عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَهُ يَقُولُ بَيْنَا نَحْنُ فِي الْمَسْجِدِ يَوْمَ الْجُمُعَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ تَقَطَّعَتِ السُّبُلُ وَهَلَكَتِ الأَمْوَالُ وَأَجْدَبَ الْبِلاَدُ فَادْعُ اللَّهَ أَنْ يَسْقِيَنَا ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ حِذَاءَ وَجْهِهِ فَقَالَ ‏"‏ اللَّهُمَّ اسْقِنَا ‏"‏ ‏.‏ فَوَاللَّهِ مَا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمِنْبَرِ حَتَّى أُوسِعْنَا مَطَرًا وَأُمْطِرْنَا ذَلِكَ الْيَوْمَ إِلَى الْجُمُعَةِ الأُخْرَى فَقَامَ رَجُلٌ - لاَ أَدْرِي هُوَ الَّذِي قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم اسْتَسْقِ لَنَا أَمْ لاَ - فَقَالَ يَا رَسُولَ اللَّهِ انْقَطَعَتِ السُّبُلُ وَهَلَكَتِ الأَمْوَالُ مِنْ كَثْرَةِ الْمَاءِ فَادْعُ اللَّهَ أَنْ يُمْسِكَ عَنَّا الْمَاءَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا وَلَكِنْ عَلَى الْجِبَالِ وَمَنَابِتِ الشَّجَرِ ‏"‏ ‏.‏ قَالَ وَاللَّهِ مَا هُوَ إِلاَّ أَنْ تَكَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ تَمَزَّقَ السَّحَابُ حَتَّى مَا نَرَى مِنْهُ شَيْئًا ‏.‏\hadithno{1515}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that he said:"While we were in the masjid on Friday and the Messenger of Allah (ﷺ) was addressing the people, a man stood up and said: 'O Messenger of Allah, the routes have been cut off, our wealth has been destroyed and prices have gone up. Pray to Allah (SWT) to give us rain.' So the Messenger of Allah (ﷺ) raised his hands in level with his face and said: 'O Allah, give us rain.' By Allah (SWT), the Messenger of Allah (ﷺ) had not come down from the minbar before it started to pour with rain, and it rained from that day until the following Friday. Then a man stood up- I do not know if he was the same man who had asked the Messenger of Allah (ﷺ) to pray for rain for us or not- and said: 'O Messenger of Allah, the routes have been cut off, and our wealth has been destroyed because there is too much water. Pray to Allah (SWT ) to stop the rain for us.' The Messenger of Allah (ﷺ) said: 'O Allah, around us and not on us, rather on the mountains and places where trees grow.' By Allah, hardly had the Messenger of Allah (ﷺ) spoken these words than the clouds split apart (and vanished) until we could not see anything of them}}
\hadithdefcmd{nasai}{1516}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي أَبُو هِشَامٍ الْمُغِيرَةُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي وُهَيْبٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ اسْقِنَا ‏"‏ ‏.‏\hadithno{1516}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that:The Prophet (ﷺ) said: "Allahumma sqina (O Allah, give us rain)}}
\hadithdefcmd{nasai}{1517}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ بْنَ عُمَرَ، - وَهُوَ الْعُمَرِيُّ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ فَقَامَ إِلَيْهِ النَّاسُ فَصَاحُوا فَقَالُوا يَا نَبِيَّ اللَّهِ قُحِطَتِ الْمَطَرُ وَهَلَكَتِ الْبَهَائِمُ فَادْعُ اللَّهَ أَنْ يَسْقِيَنَا ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اسْقِنَا اللَّهُمَّ اسْقِنَا ‏"‏ ‏.‏ قَالَ وَايْمُ اللَّهِ مَا نَرَى فِي السَّمَاءِ قَزَعَةً مِنْ سَحَابٍ - قَالَ - فَأَنْشَأَتْ سَحَابَةٌ فَانْتَشَرَتْ ثُمَّ إِنَّهَا أُمْطِرَتْ وَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى وَانْصَرَفَ النَّاسُ فَلَمْ تَزَلْ تَمْطُرُ إِلَى يَوْمِ الْجُمُعَةِ الأُخْرَى فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ صَاحُوا إِلَيْهِ فَقَالُوا يَا نَبِيَّ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ وَتَقَطَّعَتِ السُّبُلُ فَادْعُ اللَّهَ أَنْ يَحْبِسَهَا عَنَّا ‏.‏ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ فَتَقَشَّعَتْ عَنِ الْمَدِينَةِ فَجَعَلَتْ تَمْطُرُ حَوْلَهَا وَمَا تَمْطُرُ بِالْمَدِينَةِ قَطْرَةً فَنَظَرْتُ إِلَى الْمَدِينَةِ وَإِنَّهَا لَفِي مِثْلِ الإِكْلِيلِ ‏.‏\hadithno{1517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Thabit that Anas said:"The Prophet (ﷺ) was delivering the Khutbah one Friday when the people stood up and shouted: 'O Prophet of Allah! There has been no rain and the animals have died. Pray to Allah (SWT) to send us rain.' He said: 'O Allah, send us rain; O Allah, send us rain.' By Allah (SWT), we could not see even a wisp of a cloud in the sky, then a cloud appeared and grew, and it rained. The Messenger of Allah (ﷺ) came down and prayed, and the people departed, and it continued to rain until the following Friday. When the Messenger of Allah (ﷺ) stood up to deliver the Khutbah, they called out to him and said: 'O Prophet of Allah, the houses are destroyed and the routes are cut off. Pray to Allah to take it away from us.' The Messenger of Allah (ﷺ) smiled and said: 'O Allah, around us and not on us!' Then is dispersed from Al-Madinah and rain fell around Al-Madinah but not a single drop fell on Al-Madinah. I looked, and it was in something like a ring}}
\hadithdefcmd{nasai}{1518}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ فَاسْتَقْبَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا وَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ فَادْعُ اللَّهَ أَنْ يُغِيثَنَا ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَغِثْنَا اللَّهُمَّ أَغِثْنَا ‏"‏ ‏.‏ قَالَ أَنَسٌ وَلاَ وَاللَّهِ مَا نَرَى فِي السَّمَاءِ مِنْ سَحَابَةٍ وَلاَ قَزَعَةٍ وَمَا بَيْنَنَا وَبَيْنَ سَلْعٍ مِنْ بَيْتٍ وَلاَ دَارٍ فَطَلَعَتْ سَحَابَةٌ مِثْلُ التُّرْسِ فَلَمَّا تَوَسَّطَتِ السَّمَاءَ انْتَشَرَتْ وَأَمْطَرَتْ ‏.‏ قَالَ أَنَسٌ وَلاَ وَاللَّهِ مَا رَأَيْنَا الشَّمْسَ سَبْتًا ‏.‏ قَالَ ثُمَّ دَخَلَ رَجُلٌ مِنْ ذَلِكَ الْبَابِ فِي الْجُمُعَةِ الْمُقْبِلَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ فَاسْتَقْبَلَهُ قَائِمًا فَقَالَ يَا رَسُولَ اللَّهِ صَلَّى اللَّهُ وَسَلَّمَ عَلَيْكَ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ فَادْعُ اللَّهَ أَنْ يُمْسِكَهَا عَنَّا ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا اللَّهُمَّ عَلَى الآكَامِ وَالظِّرَابِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏ ‏.‏ قَالَ فَأَقْلَعَتْ وَخَرَجْنَا نَمْشِي فِي الشَّمْسِ ‏.‏ قَالَ شَرِيكٌ سَأَلْتُ أَنَسًا أَهُوَ الرَّجُلُ الأَوَّلُ قَالَ لاَ ‏.‏\hadithno{1518}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that:A man entered the masjid when the Messenger of Allah (ﷺ) was standing and delivering the Khutbah. He turned to face the Messenger of Allah (ﷺ) standing and said: 'O Messenger of Allah, our wealth has been destroyed and the routes have been cut off. Pray to Allah (SWT) to send us rain.' The Messenger of Allah (ﷺ) raised his hands then said: "O Allah, send us rain." Anas said: "By Allah, we had not seen even a wisp of a cloud in the sky and there were no houses or buildings between us and (the mountain of ) Sal'. Then a cloud like a shield appeared, and when it reached the middle of the sky it spread and it began to rain." Anas said: "By Allah, we did not see the sun for a week. Then a man entered through that door on the following Friday, when the Messenger of Allah (ﷺ) was standing and delivering the Khutbah. He turned to face him standing and said: 'O Messenger of Allah (ﷺ), may Allah (SWT) send blessings upon you. Our wealth has been destroyed and the routes have been cut off. Pray to Allah (SWT) to withold (the rain) from us.' The Messenger of Allah (ﷺ) raised his hands and said: 'O Allah, around us and not on us.; O Allah, on the hills and mountains, the bottoms of the valleys and where the trees grow.' Then it stopped raining and we went out walking in the sun." Sharik said: 'I asked Anas: 'Was he the same man?' He said: 'No}}
\hadithdefcmd{nasai}{1519}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، وَيُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبَّادُ بْنُ تَمِيمٍ، أَنَّهُ سَمِعَ عَمَّهُ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا يَسْتَسْقِي فَحَوَّلَ إِلَى النَّاسِ ظَهْرَهُ يَدْعُو اللَّهَ وَيَسْتَقْبِلُ الْقِبْلَةَ وَحَوَّلَ رِدَاءَهُ ثُمَّ صَلَّى رَكْعَتَيْنِ ‏.‏ قَالَ ابْنُ أَبِي ذِئْبٍ فِي الْحَدِيثِ وَقَرَأَ فِيهِمَا ‏.‏\hadithno{1519}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Shihab said:"Abbad bin Tamim told me that he heard his paternal uncle, who was one of the companions of the Messenger of Allah (ﷺ) say: "The Messenger of Allah (ﷺ) went out one day to pray for rain. He turned his back toward the people, praying to Allah (SWT), and he turned to face the Qiblah. He turned his rida' around, then he prayed two rak'ahs." (One of the narrators) Ibn Abi Dhi'b said in the hadith: "And he recited in them both}}
\hadithdefcmd{nasai}{1520}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَحْيَى، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَسْتَسْقِي فَصَلَّى رَكْعَتَيْنِ وَاسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{1520}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abdullah bin Zaid that:The Prophet (ﷺ) went out to pray for rain, and he prayed two rak'ahs facing the Qiblah. (Sahih)}}
\hadithdefcmd{nasai}{1521}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، عَنْ أَبِيهِ، قَالَ أَرْسَلَنِي أَمِيرٌ مِنَ الأُمَرَاءِ إِلَى ابْنِ عَبَّاسٍ أَسْأَلُهُ عَنْ الاِسْتِسْقَاءِ، فَقَالَ ابْنُ عَبَّاسٍ مَا مَنَعَهُ أَنْ يَسْأَلَنِي، خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَوَاضِعًا مُتَبَذِّلاً مُتَخَشِّعًا مُتَضَرِّعًا فَصَلَّى رَكْعَتَيْنِ كَمَا يُصَلِّي فِي الْعِيدَيْنِ وَلَمْ يَخْطُبْ خُطْبَتَكُمْ هَذِهِ ‏.‏\hadithno{1521}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hisham bin Ishaq bin Abdullah bin Kinanah that:His father said: "One of the governors sent me to Ibn Abbas to ask him about the prayer for rain. He said: 'What kept him from asking me? The Messenger of Allah (ﷺ) went out humbly, (dressed) in a state of humility, submissiveness and beseeching, and he prayed two rak'ahs as in the Eid prayer, but he did not deliver a Khutbah like this Khutbah of yours}}
\hadithdefcmd{nasai}{1522}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ فَاسْتَسْقَى فَصَلَّى رَكْعَتَيْنِ جَهَرَ فِيهِمَا بِالْقِرَاءَةِ ‏.‏\hadithno{1522}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abbad bin Tamim from his paternal uncle that:The Prophet (ﷺ) went out and prayed for rain, then he prayed two rak'ahs in which he recited loudly}}
\hadithdefcmd{nasai}{1523}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أُمْطِرَ قَالَ ‏ "‏ اللَّهُمَّ اجْعَلْهُ صَيِّبًا نَافِعًا ‏"‏ ‏.‏\hadithno{1523}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:When it rained the Messenger of Allah would say: "Allahummaj'alhu Sayyiban nafi`a. (O Allah, make it beneficial rain)}}
\hadithdefcmd{nasai}{1524}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ مَا أَنْعَمْتُ عَلَى عِبَادِي مِنْ نِعْمَةٍ إِلاَّ أَصْبَحَ فَرِيقٌ مِنْهُمْ بِهَا كَافِرِينَ يَقُولُونَ الْكَوْكَبُ وَبِالْكَوْكَبِ ‏"‏ ‏.‏\hadithno{1524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: "Allah, the Mighty and Sublime, said: I have never sent down My favor to My slaves but a group of them became disbelievers who say; "The stars and by stars}}
\hadithdefcmd{nasai}{1525}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ مُطِرَ النَّاسُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَلَمْ تَسْمَعُوا مَاذَا قَالَ رَبُّكُمُ اللَّيْلَةَ قَالَ مَا أَنْعَمْتُ عَلَى عِبَادِي مِنْ نِعْمَةٍ إِلاَّ أَصْبَحَ طَائِفَةٌ مِنْهُمْ بِهَا كَافِرِينَ يَقُولُونَ مُطِرْنَا بِنَوْءِ كَذَا وَكَذَا فَأَمَّا مَنْ آمَنَ بِي وَحَمِدَنِي عَلَى سُقْيَاىَ فَذَلِكَ الَّذِي آمَنَ بِي وَكَفَرَ بِالْكَوْكَبِ وَمَنْ قَالَ مُطِرْنَا بِنَوْءِ كَذَا وَكَذَا فَذَاكَ الَّذِي كَفَرَ بِي وَآمَنَ بِالْكَوْكَبِ ‏"‏ ‏.‏\hadithno{1525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zaid bin Khalid Al-Juhani said:"It rained during the time of the Prophet (ﷺ) and he said: 'Have you nt heard what your Lord said this night? He said: I have never sent down any blessing upon My slaves but some of them become disbelievers thereby, saying: 'We have been given rain by such and such a star.' As for the one who believes in Me and praises Me for giving rain, that is the one who believes in Me and disbelieves in the stars. But the one who says: 'We have been given rain by such and such a star' he has disbelieved in Me and believed in the stars}}
\hadithdefcmd{nasai}{1526}{أَخْبَرَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ عَتَّابِ بْنِ حُنَيْنٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَمْسَكَ اللَّهُ عَزَّ وَجَلَّ الْمَطَرَ عَنْ عِبَادِهِ خَمْسَ سِنِينَ ثُمَّ أَرْسَلَهُ لأَصْبَحَتْ طَائِفَةٌ مِنَ النَّاسِ كَافِرِينَ يَقُولُونَ سُقِينَا بِنَوْءِ الْمِجْدَحِ ‏"‏ ‏.‏\hadithno{1526}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah (ﷺ) said: 'If Allah (SWT) were to withhold rain from His slaves for five years and then send it, some of the people would become disbelievers, saying: "We have been given rain by the star of Al-Mijdah}}
\hadithdefcmd{nasai}{1527}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ قُحِطَ الْمَطَرُ عَامًا فَقَامَ بَعْضُ الْمُسْلِمِينَ إِلَى النَّبِيِّ صلى الله عليه وسلم فِي يَوْمِ جُمُعَةٍ فَقَالَ يَا رَسُولَ اللَّهِ قَحَطَ الْمَطَرُ وَأَجْدَبَتِ الأَرْضُ وَهَلَكَ الْمَالُ ‏.‏ قَالَ فَرَفَعَ يَدَيْهِ وَمَا نَرَى فِي السَّمَاءِ سَحَابَةً فَمَدَّ يَدَيْهِ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ يَسْتَسْقِي اللَّهَ عَزَّ وَجَلَّ - قَالَ - فَمَا صَلَّيْنَا الْجُمُعَةَ حَتَّى أَهَمَّ الشَّابَّ الْقَرِيبَ الدَّارِ الرُّجُوعُ إِلَى أَهْلِهِ فَدَامَتْ جُمُعَةٌ فَلَمَّا كَانَتِ الْجُمُعَةُ الَّتِي تَلِيهَا قَالُوا يَا رَسُولَ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ وَاحْتَبَسَ الرُّكْبَانُ ‏.‏ قَالَ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِسُرْعَةِ مَلاَلَةِ ابْنِ آدَمَ وَقَالَ بِيَدَيْهِ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ فَتَكَشَّطَتْ عَنِ الْمَدِينَةِ ‏.‏\hadithno{1527}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"There was no rain for a year, so some of the Muslims went to the Prophet (ﷺ) one Friday and said: 'O Messenger of Allah, there has been no rain; the land has become bare and our wealth has been destroyed.' He raised his hands, and we did not see any cloud in the sky. He stretched forth his hands until I could see the whiteness of his armpits, praying to Allah (SWT) for rain. When we finished praying Jumu'ah, even a young man whose house nearby was worried about how he would get home. That lasted for a week, then on the following Friday they said: 'O Messenger of Allah, houses have been destroyed and all travel has been ceased.' The Messenger of Allah (ﷺ) smiled at how quickly the sons of Adam become weary, and he said with his hands raised: 'O Allah, around us and not on us,' and it dispersed from Al-Madinah}}
\hadithdefcmd{nasai}{1528}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ أَنْبَأَنَا أَبُو عَمْرٍو الأَوْزَاعِيُّ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَصَابَ النَّاسُ سَنَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ فَقَامَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَ الْمَالُ وَجَاعَ الْعِيَالُ فَادْعُ اللَّهَ لَنَا ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ وَمَا نَرَى فِي السَّمَاءِ قَزَعَةً وَالَّذِي نَفْسِي بِيَدِهِ مَا وَضَعَهَا حَتَّى ثَارَ سَحَابٌ أَمْثَالُ الْجِبَالِ ثُمَّ لَمْ يَنْزِلْ عَنْ مِنْبَرِهِ حَتَّى رَأَيْتُ الْمَطَرَ يَتَحَادَرُ عَلَى لِحْيَتِهِ فَمُطِرْنَا يَوْمَنَا ذَلِكَ وَمِنَ الْغَدِ وَالَّذِي يَلِيهِ حَتَّى الْجُمُعَةِ الأُخْرَى فَقَامَ ذَلِكَ الأَعْرَابِيُّ أَوْ قَالَ غَيْرَهُ فَقَالَ يَا رَسُولَ اللَّهِ تَهَدَّمَ الْبِنَاءُ وَغَرِقَ الْمَالُ فَادْعُ اللَّهَ لَنَا ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ فَقَالَ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ فَمَا يُشِيرُ بِيَدِهِ إِلَى نَاحِيَةٍ مِنَ السَّحَابِ إِلاَّ انْفَرَجَتْ حَتَّى صَارَتِ الْمَدِينَةُ مِثْلَ الْجَوْبَةِ وَسَالَ الْوَادِي وَلَمْ يَجِئْ أَحَدٌ مِنْ نَاحِيَةٍ إِلاَّ أَخْبَرَ بِالْجَوْدِ ‏.‏\hadithno{1528}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"There was a drought during the time of the Messenger of Allah (ﷺ). While the Messenger of Allah (ﷺ) was giving the Khutbah on the minbar one Friday, a Bedouin stood up and said: 'O Messenger of Allah wealth has been destroyed and our children are hungry; pray to Allah for us.' The Messenger of Allah (ﷺ) raised his hands, and we could not see even a wisp of a cloud in the sky, but by the One in Whose hand is my soul, he did not lower (his hands) before clouds like mountains appeared, and he did not come down from his minbar before we saw the rain dripping from his beard. It rained that day and the next day, and the day after, until the following Friday. Then that Bedouin"- or he said, "Someone else"- "stood up and said: 'O Messenger of Allah, buildings have been destroyed and wealth has drowned; pray to Allah (SWT) for us. The Messenger of Allah (ﷺ) raised his hands and said: 'O Allah, around us and not on us.' He did not point in any direction but the clouds dispersed, until Al-Madinah became like a hole. And the valleys ran with water and no one came from any direction but he told us of the heavy rains}}
